# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import uuid  # noqa: F401
from dataclasses import dataclass
from datetime import date, datetime  # noqa: F401

import frozendict  # noqa: F401
import typing_extensions  # noqa: F401
import urllib3
from urllib3._collections import HTTPHeaderDict

from gentrace import (
    api_client,
    exceptions,
    schemas,  # noqa: F401
)
from gentrace.model.test_set import TestSet

from . import path

# Query params
LabelSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    "RequestRequiredQueryParams", {}
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    "RequestOptionalQueryParams",
    {
        "label": typing.Union[
            LabelSchema,
            str,
        ],
    },
    total=False,
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_label = api_client.QueryParameter(
    name="label",
    style=api_client.ParameterStyle.FORM,
    schema=LabelSchema,
    explode=True,
)
_auth = [
    "bearerAuth",
]


class SchemaFor200ResponseBodyApplicationJson(schemas.DictSchema):
    class MetaOapg:
        required = {
            "testSets",
        }

        class properties:
            class testSets(schemas.ListSchema):
                class MetaOapg:
                    @staticmethod
                    def items() -> typing.Type["TestSet"]:
                        return TestSet

                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple["TestSet"], typing.List["TestSet"]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "testSets":
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )

                def __getitem__(self, i: int) -> "TestSet":
                    return super().__getitem__(i)

            __annotations__ = {
                "testSets": testSets,
            }

    testSets: MetaOapg.properties.testSets

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["testSets"]
    ) -> MetaOapg.properties.testSets:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(
        self, name: typing.Union[typing_extensions.Literal["testSets",], str]
    ):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["testSets"]
    ) -> MetaOapg.properties.testSets:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(
        self, name: typing.Union[typing_extensions.Literal["testSets",], str]
    ):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        testSets: typing.Union[
            MetaOapg.properties.testSets,
            list,
            tuple,
        ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "SchemaFor200ResponseBodyApplicationJson":
        return super().__new__(
            cls,
            *_args,
            testSets=testSets,
            _configuration=_configuration,
            **kwargs,
        )


class SchemaFor200ResponseBodyApplicationJsonCharsetutf8(schemas.DictSchema):
    class MetaOapg:
        required = {
            "testSets",
        }

        class properties:
            class testSets(schemas.ListSchema):
                class MetaOapg:
                    @staticmethod
                    def items() -> typing.Type["TestSet"]:
                        return TestSet

                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple["TestSet"], typing.List["TestSet"]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "testSets":
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )

                def __getitem__(self, i: int) -> "TestSet":
                    return super().__getitem__(i)

            __annotations__ = {
                "testSets": testSets,
            }

    testSets: MetaOapg.properties.testSets

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["testSets"]
    ) -> MetaOapg.properties.testSets:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(
        self, name: typing.Union[typing_extensions.Literal["testSets",], str]
    ):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["testSets"]
    ) -> MetaOapg.properties.testSets:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(
        self, name: typing.Union[typing_extensions.Literal["testSets",], str]
    ):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        testSets: typing.Union[
            MetaOapg.properties.testSets,
            list,
            tuple,
        ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "SchemaFor200ResponseBodyApplicationJsonCharsetutf8":
        return super().__new__(
            cls,
            *_args,
            testSets=testSets,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
        SchemaFor200ResponseBodyApplicationJsonCharsetutf8,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        "application/json": api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson
        ),
        "application/json; charset=utf-8": api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJsonCharsetutf8
        ),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    "200": _response_for_200,
    "400": _response_for_400,
    "500": _response_for_500,
}
_all_accept_content_types = (
    "application/json",
    "application/json; charset=utf-8",
)


class BaseApi(api_client.Api):
    @typing.overload
    def _test_sets_get_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def _test_sets_get_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization:
        ...

    @typing.overload
    def _test_sets_get_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[ApiResponseFor200, api_client.ApiResponseWithoutDeserialization,]:
        ...

    def _test_sets_get_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get test sets, optionally filtered by label
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (request_query_label,):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(
                parameter_data, prefix_separator_iterator
            )
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add("Accept", accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method="get".upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(
                response=response
            )
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(
                    response, self.api_client.configuration
                )
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(
                    response=response
                )

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response,
            )

        return api_response


class TestSetsGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def test_sets_get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def test_sets_get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization:
        ...

    @typing.overload
    def test_sets_get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[ApiResponseFor200, api_client.ApiResponseWithoutDeserialization,]:
        ...

    def test_sets_get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._test_sets_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization,
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization:
        ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[ApiResponseFor200, api_client.ApiResponseWithoutDeserialization,]:
        ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._test_sets_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization,
        )



# coding: utf-8

"""
    Gentrace API

    These API routes are designed to ingest events from clients.  # noqa: E501

    The version of the OpenAPI document: 0.9.0
    Generated by: https://openapi-generator.tech
"""

from gentrace.paths.pipeline_run.post import PipelineRunPost
from gentrace.paths.test_case.get import TestCaseGet
from gentrace.paths.test_run.get import TestRunGet
from gentrace.paths.test_run.post import TestRunPost
from gentrace.paths.test_sets.get import TestSetsGet


class CoreApi(
    PipelineRunPost,
    TestCaseGet,
    TestRunGet,
    TestRunPost,
    TestSetsGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    pass



# coding: utf-8

"""
    Gentrace API

    These API routes are designed to ingest events from clients.  # noqa: E501

    The version of the OpenAPI document: 0.9.0
    Generated by: https://openapi-generator.tech
"""

import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import uuid  # noqa: F401
from datetime import date, datetime  # noqa: F401

import frozendict  # noqa: F401
import typing_extensions  # noqa: F401

from gentrace import schemas  # noqa: F401

class TestCase(schemas.DictSchema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    class MetaOapg:
        required = {
            "createdAt",
            "inputs",
            "name",
            "setId",
            "id",
            "updatedAt",
        }

        class properties:
            id = schemas.UUIDSchema
            createdAt = schemas.DateTimeSchema
            updatedAt = schemas.DateTimeSchema

            class inputs(schemas.DictSchema):
                class MetaOapg:
                    additional_properties = schemas.AnyTypeSchema
                def __getitem__(
                    self, name: typing.Union[str,]
                ) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                def get_item_oapg(
                    self, name: typing.Union[str,]
                ) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
                def __new__(
                    cls,
                    *_args: typing.Union[
                        dict,
                        frozendict.frozendict,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[
                        MetaOapg.additional_properties,
                        dict,
                        frozendict.frozendict,
                        str,
                        date,
                        datetime,
                        uuid.UUID,
                        int,
                        float,
                        decimal.Decimal,
                        bool,
                        None,
                        list,
                        tuple,
                        bytes,
                        io.FileIO,
                        io.BufferedReader,
                    ],
                ) -> "inputs":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            name = schemas.StrSchema
            setId = schemas.UUIDSchema

            class archivedAt(
                schemas.DateTimeBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin,
            ):
                class MetaOapg:
                    format = "date-time"
                def __new__(
                    cls,
                    *_args: typing.Union[
                        None,
                        str,
                        datetime,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "archivedAt":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )

            class expectedOutputs(
                schemas.DictBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneFrozenDictMixin,
            ):
                def __new__(
                    cls,
                    *_args: typing.Union[
                        dict,
                        frozendict.frozendict,
                        None,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[
                        schemas.AnyTypeSchema,
                        dict,
                        frozendict.frozendict,
                        str,
                        date,
                        datetime,
                        uuid.UUID,
                        int,
                        float,
                        decimal.Decimal,
                        None,
                        list,
                        tuple,
                        bytes,
                    ],
                ) -> "expectedOutputs":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "id": id,
                "createdAt": createdAt,
                "updatedAt": updatedAt,
                "inputs": inputs,
                "name": name,
                "setId": setId,
                "archivedAt": archivedAt,
                "expectedOutputs": expectedOutputs,
            }
    createdAt: MetaOapg.properties.createdAt
    inputs: MetaOapg.properties.inputs
    name: MetaOapg.properties.name
    setId: MetaOapg.properties.setId
    id: MetaOapg.properties.id
    updatedAt: MetaOapg.properties.updatedAt

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["id"]
    ) -> MetaOapg.properties.id: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["createdAt"]
    ) -> MetaOapg.properties.createdAt: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["updatedAt"]
    ) -> MetaOapg.properties.updatedAt: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["inputs"]
    ) -> MetaOapg.properties.inputs: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["name"]
    ) -> MetaOapg.properties.name: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["setId"]
    ) -> MetaOapg.properties.setId: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["archivedAt"]
    ) -> MetaOapg.properties.archivedAt: ...
    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["expectedOutputs"]
    ) -> MetaOapg.properties.expectedOutputs: ...
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    def __getitem__(
        self,
        name: typing.Union[
            typing_extensions.Literal[
                "id",
                "createdAt",
                "updatedAt",
                "inputs",
                "name",
                "setId",
                "archivedAt",
                "expectedOutputs",
            ],
            str,
        ],
    ):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["id"]
    ) -> MetaOapg.properties.id: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["createdAt"]
    ) -> MetaOapg.properties.createdAt: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["updatedAt"]
    ) -> MetaOapg.properties.updatedAt: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["inputs"]
    ) -> MetaOapg.properties.inputs: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["name"]
    ) -> MetaOapg.properties.name: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["setId"]
    ) -> MetaOapg.properties.setId: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["archivedAt"]
    ) -> typing.Union[MetaOapg.properties.archivedAt, schemas.Unset]: ...
    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["expectedOutputs"]
    ) -> typing.Union[MetaOapg.properties.expectedOutputs, schemas.Unset]: ...
    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    def get_item_oapg(
        self,
        name: typing.Union[
            typing_extensions.Literal[
                "id",
                "createdAt",
                "updatedAt",
                "inputs",
                "name",
                "setId",
                "archivedAt",
                "expectedOutputs",
            ],
            str,
        ],
    ):
        return super().get_item_oapg(name)
    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        createdAt: typing.Union[
            MetaOapg.properties.createdAt,
            str,
            datetime,
        ],
        inputs: typing.Union[
            MetaOapg.properties.inputs,
            dict,
            frozendict.frozendict,
        ],
        name: typing.Union[
            MetaOapg.properties.name,
            str,
        ],
        setId: typing.Union[
            MetaOapg.properties.setId,
            str,
            uuid.UUID,
        ],
        id: typing.Union[
            MetaOapg.properties.id,
            str,
            uuid.UUID,
        ],
        updatedAt: typing.Union[
            MetaOapg.properties.updatedAt,
            str,
            datetime,
        ],
        archivedAt: typing.Union[
            MetaOapg.properties.archivedAt, None, str, datetime, schemas.Unset
        ] = schemas.unset,
        expectedOutputs: typing.Union[
            MetaOapg.properties.expectedOutputs,
            dict,
            frozendict.frozendict,
            None,
            schemas.Unset,
        ] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "TestCase":
        return super().__new__(
            cls,
            *_args,
            createdAt=createdAt,
            inputs=inputs,
            name=name,
            setId=setId,
            id=id,
            updatedAt=updatedAt,
            archivedAt=archivedAt,
            expectedOutputs=expectedOutputs,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from gentrace.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    PIPELINERUN = "/pipeline-run"
    TESTCASE = "/test-case"
    TESTRUN = "/test-run"
    TESTSETS = "/test-sets"



import typing_extensions

from gentrace.apis.paths.pipeline_run import PipelineRun
from gentrace.apis.paths.test_case import TestCase
from gentrace.apis.paths.test_run import TestRun
from gentrace.apis.paths.test_sets import TestSets
from gentrace.paths import PathValues

PathToApi = typing_extensions.TypedDict(
    "PathToApi",
    {
        PathValues.PIPELINERUN: PipelineRun,
        PathValues.TESTCASE: TestCase,
        PathValues.TESTRUN: TestRun,
        PathValues.TESTSETS: TestSets,
    },
)

path_to_api = PathToApi(
    {
        PathValues.PIPELINERUN: PipelineRun,
        PathValues.TESTCASE: TestCase,
        PathValues.TESTRUN: TestRun,
        PathValues.TESTSETS: TestSets,
    }
)



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import uuid  # noqa: F401
from dataclasses import dataclass
from datetime import date, datetime  # noqa: F401

import frozendict  # noqa: F401
import typing_extensions  # noqa: F401
import urllib3
from urllib3._collections import HTTPHeaderDict

from gentrace import (
    api_client,
    exceptions,
    schemas,  # noqa: F401
)

from . import path

# body param


class SchemaForRequestBodyApplicationJson(schemas.DictSchema):
    class MetaOapg:
        required = {
            "testResults",
            "setId",
        }

        class properties:
            setId = schemas.UUIDSchema

            class branch(
                schemas.StrBase, schemas.NoneBase, schemas.Schema, schemas.NoneStrMixin
            ):
                def __new__(
                    cls,
                    *_args: typing.Union[
                        None,
                        str,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "branch":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )

            class commit(
                schemas.StrBase, schemas.NoneBase, schemas.Schema, schemas.NoneStrMixin
            ):
                def __new__(
                    cls,
                    *_args: typing.Union[
                        None,
                        str,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "commit":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )

            class name(
                schemas.StrBase, schemas.NoneBase, schemas.Schema, schemas.NoneStrMixin
            ):
                def __new__(
                    cls,
                    *_args: typing.Union[
                        None,
                        str,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "name":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )

            class testResults(schemas.ListSchema):
                class MetaOapg:
                    class items(schemas.DictSchema):
                        class MetaOapg:
                            required = {
                                "inputs",
                                "caseId",
                            }

                            class properties:
                                class id(
                                    schemas.UUIDBase,
                                    schemas.StrBase,
                                    schemas.NoneBase,
                                    schemas.Schema,
                                    schemas.NoneStrMixin,
                                ):
                                    class MetaOapg:
                                        format = "uuid"

                                    def __new__(
                                        cls,
                                        *_args: typing.Union[
                                            None,
                                            str,
                                            uuid.UUID,
                                        ],
                                        _configuration: typing.Optional[
                                            schemas.Configuration
                                        ] = None,
                                    ) -> "id":
                                        return super().__new__(
                                            cls,
                                            *_args,
                                            _configuration=_configuration,
                                        )

                                caseId = schemas.UUIDSchema

                                class inputs(schemas.DictSchema):
                                    class MetaOapg:
                                        additional_properties = schemas.AnyTypeSchema

                                    def __getitem__(
                                        self, name: typing.Union[str,]
                                    ) -> MetaOapg.additional_properties:
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)

                                    def get_item_oapg(
                                        self, name: typing.Union[str,]
                                    ) -> MetaOapg.additional_properties:
                                        return super().get_item_oapg(name)

                                    def __new__(
                                        cls,
                                        *_args: typing.Union[
                                            dict,
                                            frozendict.frozendict,
                                        ],
                                        _configuration: typing.Optional[
                                            schemas.Configuration
                                        ] = None,
                                        **kwargs: typing.Union[
                                            MetaOapg.additional_properties,
                                            dict,
                                            frozendict.frozendict,
                                            str,
                                            date,
                                            datetime,
                                            uuid.UUID,
                                            int,
                                            float,
                                            decimal.Decimal,
                                            bool,
                                            None,
                                            list,
                                            tuple,
                                            bytes,
                                            io.FileIO,
                                            io.BufferedReader,
                                        ],
                                    ) -> "inputs":
                                        return super().__new__(
                                            cls,
                                            *_args,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )

                                class outputs(schemas.DictSchema):
                                    class MetaOapg:
                                        additional_properties = schemas.AnyTypeSchema

                                    def __getitem__(
                                        self, name: typing.Union[str,]
                                    ) -> MetaOapg.additional_properties:
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)

                                    def get_item_oapg(
                                        self, name: typing.Union[str,]
                                    ) -> MetaOapg.additional_properties:
                                        return super().get_item_oapg(name)

                                    def __new__(
                                        cls,
                                        *_args: typing.Union[
                                            dict,
                                            frozendict.frozendict,
                                        ],
                                        _configuration: typing.Optional[
                                            schemas.Configuration
                                        ] = None,
                                        **kwargs: typing.Union[
                                            MetaOapg.additional_properties,
                                            dict,
                                            frozendict.frozendict,
                                            str,
                                            date,
                                            datetime,
                                            uuid.UUID,
                                            int,
                                            float,
                                            decimal.Decimal,
                                            bool,
                                            None,
                                            list,
                                            tuple,
                                            bytes,
                                            io.FileIO,
                                            io.BufferedReader,
                                        ],
                                    ) -> "outputs":
                                        return super().__new__(
                                            cls,
                                            *_args,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )

                                output = schemas.StrSchema

                                class outputSteps(
                                    schemas.ListBase,
                                    schemas.NoneBase,
                                    schemas.Schema,
                                    schemas.NoneTupleMixin,
                                ):
                                    class MetaOapg:
                                        class items(schemas.DictSchema):
                                            class MetaOapg:
                                                required = {
                                                    "output",
                                                    "key",
                                                }

                                                class properties:
                                                    class key(schemas.StrSchema):
                                                        class MetaOapg:
                                                            max_length = 100
                                                            min_length = 1

                                                    output = schemas.StrSchema

                                                    class inputs(
                                                        schemas.DictBase,
                                                        schemas.NoneBase,
                                                        schemas.Schema,
                                                        schemas.NoneFrozenDictMixin,
                                                    ):
                                                        class MetaOapg:
                                                            additional_properties = (
                                                                schemas.StrSchema
                                                            )

                                                        def __getitem__(
                                                            self,
                                                            name: typing.Union[str,],
                                                        ) -> (
                                                            MetaOapg.additional_properties
                                                        ):
                                                            # dict_instance[name] accessor
                                                            return super().__getitem__(
                                                                name
                                                            )

                                                        def get_item_oapg(
                                                            self,
                                                            name: typing.Union[str,],
                                                        ) -> (
                                                            MetaOapg.additional_properties
                                                        ):
                                                            return (
                                                                super().get_item_oapg(
                                                                    name
                                                                )
                                                            )

                                                        def __new__(
                                                            cls,
                                                            *_args: typing.Union[
                                                                dict,
                                                                frozendict.frozendict,
                                                                None,
                                                            ],
                                                            _configuration: typing.Optional[
                                                                schemas.Configuration
                                                            ] = None,
                                                            **kwargs: typing.Union[
                                                                MetaOapg.additional_properties,
                                                                str,
                                                            ],
                                                        ) -> "inputs":
                                                            return super().__new__(
                                                                cls,
                                                                *_args,
                                                                _configuration=_configuration,
                                                                **kwargs,
                                                            )

                                                    __annotations__ = {
                                                        "key": key,
                                                        "output": output,
                                                        "inputs": inputs,
                                                    }

                                            output: MetaOapg.properties.output
                                            key: MetaOapg.properties.key

                                            @typing.overload
                                            def __getitem__(
                                                self,
                                                name: typing_extensions.Literal["key"],
                                            ) -> MetaOapg.properties.key:
                                                ...

                                            @typing.overload
                                            def __getitem__(
                                                self,
                                                name: typing_extensions.Literal[
                                                    "output"
                                                ],
                                            ) -> MetaOapg.properties.output:
                                                ...

                                            @typing.overload
                                            def __getitem__(
                                                self,
                                                name: typing_extensions.Literal[
                                                    "inputs"
                                                ],
                                            ) -> MetaOapg.properties.inputs:
                                                ...

                                            @typing.overload
                                            def __getitem__(
                                                self, name: str
                                            ) -> schemas.UnsetAnyTypeSchema:
                                                ...

                                            def __getitem__(
                                                self,
                                                name: typing.Union[
                                                    typing_extensions.Literal[
                                                        "key",
                                                        "output",
                                                        "inputs",
                                                    ],
                                                    str,
                                                ],
                                            ):
                                                # dict_instance[name] accessor
                                                return super().__getitem__(name)

                                            @typing.overload
                                            def get_item_oapg(
                                                self,
                                                name: typing_extensions.Literal["key"],
                                            ) -> MetaOapg.properties.key:
                                                ...

                                            @typing.overload
                                            def get_item_oapg(
                                                self,
                                                name: typing_extensions.Literal[
                                                    "output"
                                                ],
                                            ) -> MetaOapg.properties.output:
                                                ...

                                            @typing.overload
                                            def get_item_oapg(
                                                self,
                                                name: typing_extensions.Literal[
                                                    "inputs"
                                                ],
                                            ) -> typing.Union[
                                                MetaOapg.properties.inputs,
                                                schemas.Unset,
                                            ]:
                                                ...

                                            @typing.overload
                                            def get_item_oapg(
                                                self, name: str
                                            ) -> typing.Union[
                                                schemas.UnsetAnyTypeSchema,
                                                schemas.Unset,
                                            ]:
                                                ...

                                            def get_item_oapg(
                                                self,
                                                name: typing.Union[
                                                    typing_extensions.Literal[
                                                        "key",
                                                        "output",
                                                        "inputs",
                                                    ],
                                                    str,
                                                ],
                                            ):
                                                return super().get_item_oapg(name)

                                            def __new__(
                                                cls,
                                                *_args: typing.Union[
                                                    dict,
                                                    frozendict.frozendict,
                                                ],
                                                output: typing.Union[
                                                    MetaOapg.properties.output,
                                                    str,
                                                ],
                                                key: typing.Union[
                                                    MetaOapg.properties.key,
                                                    str,
                                                ],
                                                inputs: typing.Union[
                                                    MetaOapg.properties.inputs,
                                                    dict,
                                                    frozendict.frozendict,
                                                    None,
                                                    schemas.Unset,
                                                ] = schemas.unset,
                                                _configuration: typing.Optional[
                                                    schemas.Configuration
                                                ] = None,
                                                **kwargs: typing.Union[
                                                    schemas.AnyTypeSchema,
                                                    dict,
                                                    frozendict.frozendict,
                                                    str,
                                                    date,
                                                    datetime,
                                                    uuid.UUID,
                                                    int,
                                                    float,
                                                    decimal.Decimal,
                                                    None,
                                                    list,
                                                    tuple,
                                                    bytes,
                                                ],
                                            ) -> "items":
                                                return super().__new__(
                                                    cls,
                                                    *_args,
                                                    output=output,
                                                    key=key,
                                                    inputs=inputs,
                                                    _configuration=_configuration,
                                                    **kwargs,
                                                )

                                        min_items = 1

                                    def __new__(
                                        cls,
                                        *_args: typing.Union[
                                            list,
                                            tuple,
                                            None,
                                        ],
                                        _configuration: typing.Optional[
                                            schemas.Configuration
                                        ] = None,
                                    ) -> "outputSteps":
                                        return super().__new__(
                                            cls,
                                            *_args,
                                            _configuration=_configuration,
                                        )

                                __annotations__ = {
                                    "id": id,
                                    "caseId": caseId,
                                    "inputs": inputs,
                                    "outputs": outputs,
                                    "output": output,
                                    "outputSteps": outputSteps,
                                }

                        inputs: MetaOapg.properties.inputs
                        caseId: MetaOapg.properties.caseId

                        @typing.overload
                        def __getitem__(
                            self, name: typing_extensions.Literal["id"]
                        ) -> MetaOapg.properties.id:
                            ...

                        @typing.overload
                        def __getitem__(
                            self, name: typing_extensions.Literal["caseId"]
                        ) -> MetaOapg.properties.caseId:
                            ...

                        @typing.overload
                        def __getitem__(
                            self, name: typing_extensions.Literal["inputs"]
                        ) -> MetaOapg.properties.inputs:
                            ...

                        @typing.overload
                        def __getitem__(
                            self, name: typing_extensions.Literal["outputs"]
                        ) -> MetaOapg.properties.outputs:
                            ...

                        @typing.overload
                        def __getitem__(
                            self, name: typing_extensions.Literal["output"]
                        ) -> MetaOapg.properties.output:
                            ...

                        @typing.overload
                        def __getitem__(
                            self, name: typing_extensions.Literal["outputSteps"]
                        ) -> MetaOapg.properties.outputSteps:
                            ...

                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
                            ...

                        def __getitem__(
                            self,
                            name: typing.Union[
                                typing_extensions.Literal[
                                    "id",
                                    "caseId",
                                    "inputs",
                                    "outputs",
                                    "output",
                                    "outputSteps",
                                ],
                                str,
                            ],
                        ):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)

                        @typing.overload
                        def get_item_oapg(
                            self, name: typing_extensions.Literal["id"]
                        ) -> typing.Union[MetaOapg.properties.id, schemas.Unset]:
                            ...

                        @typing.overload
                        def get_item_oapg(
                            self, name: typing_extensions.Literal["caseId"]
                        ) -> MetaOapg.properties.caseId:
                            ...

                        @typing.overload
                        def get_item_oapg(
                            self, name: typing_extensions.Literal["inputs"]
                        ) -> MetaOapg.properties.inputs:
                            ...

                        @typing.overload
                        def get_item_oapg(
                            self, name: typing_extensions.Literal["outputs"]
                        ) -> typing.Union[MetaOapg.properties.outputs, schemas.Unset]:
                            ...

                        @typing.overload
                        def get_item_oapg(
                            self, name: typing_extensions.Literal["output"]
                        ) -> typing.Union[MetaOapg.properties.output, schemas.Unset]:
                            ...

                        @typing.overload
                        def get_item_oapg(
                            self, name: typing_extensions.Literal["outputSteps"]
                        ) -> typing.Union[
                            MetaOapg.properties.outputSteps, schemas.Unset
                        ]:
                            ...

                        @typing.overload
                        def get_item_oapg(
                            self, name: str
                        ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
                            ...

                        def get_item_oapg(
                            self,
                            name: typing.Union[
                                typing_extensions.Literal[
                                    "id",
                                    "caseId",
                                    "inputs",
                                    "outputs",
                                    "output",
                                    "outputSteps",
                                ],
                                str,
                            ],
                        ):
                            return super().get_item_oapg(name)

                        def __new__(
                            cls,
                            *_args: typing.Union[
                                dict,
                                frozendict.frozendict,
                            ],
                            inputs: typing.Union[
                                MetaOapg.properties.inputs,
                                dict,
                                frozendict.frozendict,
                            ],
                            caseId: typing.Union[
                                MetaOapg.properties.caseId,
                                str,
                                uuid.UUID,
                            ],
                            id: typing.Union[
                                MetaOapg.properties.id,
                                None,
                                str,
                                uuid.UUID,
                                schemas.Unset,
                            ] = schemas.unset,
                            outputs: typing.Union[
                                MetaOapg.properties.outputs,
                                dict,
                                frozendict.frozendict,
                                schemas.Unset,
                            ] = schemas.unset,
                            output: typing.Union[
                                MetaOapg.properties.output, str, schemas.Unset
                            ] = schemas.unset,
                            outputSteps: typing.Union[
                                MetaOapg.properties.outputSteps,
                                list,
                                tuple,
                                None,
                                schemas.Unset,
                            ] = schemas.unset,
                            _configuration: typing.Optional[
                                schemas.Configuration
                            ] = None,
                            **kwargs: typing.Union[
                                schemas.AnyTypeSchema,
                                dict,
                                frozendict.frozendict,
                                str,
                                date,
                                datetime,
                                uuid.UUID,
                                int,
                                float,
                                decimal.Decimal,
                                None,
                                list,
                                tuple,
                                bytes,
                            ],
                        ) -> "items":
                            return super().__new__(
                                cls,
                                *_args,
                                inputs=inputs,
                                caseId=caseId,
                                id=id,
                                outputs=outputs,
                                output=output,
                                outputSteps=outputSteps,
                                _configuration=_configuration,
                                **kwargs,
                            )

                def __new__(
                    cls,
                    _arg: typing.Union[
                        typing.Tuple[
                            typing.Union[
                                MetaOapg.items,
                                dict,
                                frozendict.frozendict,
                            ]
                        ],
                        typing.List[
                            typing.Union[
                                MetaOapg.items,
                                dict,
                                frozendict.frozendict,
                            ]
                        ],
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "testResults":
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )

                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)

            __annotations__ = {
                "setId": setId,
                "branch": branch,
                "commit": commit,
                "name": name,
                "testResults": testResults,
            }

    testResults: MetaOapg.properties.testResults
    setId: MetaOapg.properties.setId

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["setId"]
    ) -> MetaOapg.properties.setId:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["branch"]
    ) -> MetaOapg.properties.branch:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["commit"]
    ) -> MetaOapg.properties.commit:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["name"]
    ) -> MetaOapg.properties.name:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["testResults"]
    ) -> MetaOapg.properties.testResults:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(
        self,
        name: typing.Union[
            typing_extensions.Literal[
                "setId",
                "branch",
                "commit",
                "name",
                "testResults",
            ],
            str,
        ],
    ):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["setId"]
    ) -> MetaOapg.properties.setId:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["branch"]
    ) -> typing.Union[MetaOapg.properties.branch, schemas.Unset]:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["commit"]
    ) -> typing.Union[MetaOapg.properties.commit, schemas.Unset]:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["name"]
    ) -> typing.Union[MetaOapg.properties.name, schemas.Unset]:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["testResults"]
    ) -> MetaOapg.properties.testResults:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(
        self,
        name: typing.Union[
            typing_extensions.Literal[
                "setId",
                "branch",
                "commit",
                "name",
                "testResults",
            ],
            str,
        ],
    ):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        testResults: typing.Union[
            MetaOapg.properties.testResults,
            list,
            tuple,
        ],
        setId: typing.Union[
            MetaOapg.properties.setId,
            str,
            uuid.UUID,
        ],
        branch: typing.Union[
            MetaOapg.properties.branch, None, str, schemas.Unset
        ] = schemas.unset,
        commit: typing.Union[
            MetaOapg.properties.commit, None, str, schemas.Unset
        ] = schemas.unset,
        name: typing.Union[
            MetaOapg.properties.name, None, str, schemas.Unset
        ] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "SchemaForRequestBodyApplicationJson":
        return super().__new__(
            cls,
            *_args,
            testResults=testResults,
            setId=setId,
            branch=branch,
            commit=commit,
            name=name,
            _configuration=_configuration,
            **kwargs,
        )


request_body_any_type = api_client.RequestBody(
    content={
        "application/json": api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson
        ),
    },
    required=True,
)
_auth = [
    "bearerAuth",
]


class SchemaFor200ResponseBodyApplicationJson(schemas.DictSchema):
    class MetaOapg:
        required = {
            "runId",
        }

        class properties:
            runId = schemas.UUIDSchema
            __annotations__ = {
                "runId": runId,
            }

    runId: MetaOapg.properties.runId

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["runId"]
    ) -> MetaOapg.properties.runId:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(self, name: typing.Union[typing_extensions.Literal["runId",], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["runId"]
    ) -> MetaOapg.properties.runId:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(
        self, name: typing.Union[typing_extensions.Literal["runId",], str]
    ):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        runId: typing.Union[
            MetaOapg.properties.runId,
            str,
            uuid.UUID,
        ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "SchemaFor200ResponseBodyApplicationJson":
        return super().__new__(
            cls,
            *_args,
            runId=runId,
            _configuration=_configuration,
            **kwargs,
        )


class SchemaFor200ResponseBodyApplicationJsonCharsetutf8(schemas.DictSchema):
    class MetaOapg:
        required = {
            "runId",
        }

        class properties:
            runId = schemas.UUIDSchema
            __annotations__ = {
                "runId": runId,
            }

    runId: MetaOapg.properties.runId

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["runId"]
    ) -> MetaOapg.properties.runId:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(self, name: typing.Union[typing_extensions.Literal["runId",], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["runId"]
    ) -> MetaOapg.properties.runId:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(
        self, name: typing.Union[typing_extensions.Literal["runId",], str]
    ):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        runId: typing.Union[
            MetaOapg.properties.runId,
            str,
            uuid.UUID,
        ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "SchemaFor200ResponseBodyApplicationJsonCharsetutf8":
        return super().__new__(
            cls,
            *_args,
            runId=runId,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
        SchemaFor200ResponseBodyApplicationJsonCharsetutf8,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        "application/json": api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson
        ),
        "application/json; charset=utf-8": api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJsonCharsetutf8
        ),
    },
)
_status_code_to_response = {
    "200": _response_for_200,
}
_all_accept_content_types = (
    "application/json",
    "application/json; charset=utf-8",
)


class BaseApi(api_client.Api):
    @typing.overload
    def _test_run_post_oapg(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: typing_extensions.Literal["application/json"] = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def _test_run_post_oapg(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def _test_run_post_oapg(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization:
        ...

    @typing.overload
    def _test_run_post_oapg(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[ApiResponseFor200, api_client.ApiResponseWithoutDeserialization,]:
        ...

    def _test_run_post_oapg(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = "application/json",
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Create a new test run from test results
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        used_path = path.value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add("Accept", accept_content_type)

        if body is schemas.unset:
            raise exceptions.ApiValueError(
                "The required body parameter has an invalid value of: unset. Set a valid value instead"
            )
        _fields = None
        _body = None
        serialized_data = request_body_any_type.serialize(body, content_type)
        _headers.add("Content-Type", content_type)
        if "fields" in serialized_data:
            _fields = serialized_data["fields"]
        elif "body" in serialized_data:
            _body = serialized_data["body"]
        response = self.api_client.call_api(
            resource_path=used_path,
            method="post".upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(
                response=response
            )
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(
                    response, self.api_client.configuration
                )
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(
                    response=response
                )

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response,
            )

        return api_response


class TestRunPost(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def test_run_post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: typing_extensions.Literal["application/json"] = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def test_run_post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def test_run_post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization:
        ...

    @typing.overload
    def test_run_post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[ApiResponseFor200, api_client.ApiResponseWithoutDeserialization,]:
        ...

    def test_run_post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = "application/json",
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._test_run_post_oapg(
            body=body,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization,
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: typing_extensions.Literal["application/json"] = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[ApiResponseFor200,]:
        ...

    @typing.overload
    def post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        skip_deserialization: typing_extensions.Literal[True],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization:
        ...

    @typing.overload
    def post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = ...,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[ApiResponseFor200, api_client.ApiResponseWithoutDeserialization,]:
        ...

    def post(
        self,
        body: typing.Union[
            SchemaForRequestBodyApplicationJson,
            dict,
            frozendict.frozendict,
        ],
        content_type: str = "application/json",
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._test_run_post_oapg(
            body=body,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization,
        )



# coding: utf-8

"""
    Gentrace API

    These API routes are designed to ingest events from clients.  # noqa: E501

    The version of the OpenAPI document: 0.9.0
    Generated by: https://openapi-generator.tech
"""

import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import uuid  # noqa: F401
from datetime import date, datetime  # noqa: F401

import frozendict  # noqa: F401
import typing_extensions  # noqa: F401

from gentrace import schemas  # noqa: F401


class TestSet(schemas.DictSchema):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    class MetaOapg:
        required = {
            "organizationId",
            "createdAt",
            "cases",
            "name",
            "id",
            "labels",
            "updatedAt",
        }

        class properties:
            id = schemas.UUIDSchema
            createdAt = schemas.DateTimeSchema
            updatedAt = schemas.DateTimeSchema

            class cases(schemas.ListSchema):
                class MetaOapg:
                    @staticmethod
                    def items() -> typing.Type["TestCase"]:
                        return TestCase

                def __new__(
                    cls,
                    _arg: typing.Union[
                        typing.Tuple["TestCase"], typing.List["TestCase"]
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "cases":
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )

                def __getitem__(self, i: int) -> "TestCase":
                    return super().__getitem__(i)

            class labels(schemas.ListSchema):
                class MetaOapg:
                    items = schemas.StrSchema

                def __new__(
                    cls,
                    _arg: typing.Union[
                        typing.Tuple[
                            typing.Union[
                                MetaOapg.items,
                                str,
                            ]
                        ],
                        typing.List[
                            typing.Union[
                                MetaOapg.items,
                                str,
                            ]
                        ],
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "labels":
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )

                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)

            name = schemas.StrSchema
            organizationId = schemas.StrSchema

            class archivedAt(
                schemas.DateTimeBase,
                schemas.StrBase,
                schemas.NoneBase,
                schemas.Schema,
                schemas.NoneStrMixin,
            ):
                class MetaOapg:
                    format = "date-time"

                def __new__(
                    cls,
                    *_args: typing.Union[
                        None,
                        str,
                        datetime,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "archivedAt":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )

            class branch(
                schemas.StrBase, schemas.NoneBase, schemas.Schema, schemas.NoneStrMixin
            ):
                def __new__(
                    cls,
                    *_args: typing.Union[
                        None,
                        str,
                    ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> "branch":
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                    )

            __annotations__ = {
                "id": id,
                "createdAt": createdAt,
                "updatedAt": updatedAt,
                "cases": cases,
                "labels": labels,
                "name": name,
                "organizationId": organizationId,
                "archivedAt": archivedAt,
                "branch": branch,
            }

    organizationId: MetaOapg.properties.organizationId
    createdAt: MetaOapg.properties.createdAt
    cases: MetaOapg.properties.cases
    name: MetaOapg.properties.name
    id: MetaOapg.properties.id
    labels: MetaOapg.properties.labels
    updatedAt: MetaOapg.properties.updatedAt

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["id"]
    ) -> MetaOapg.properties.id:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["createdAt"]
    ) -> MetaOapg.properties.createdAt:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["updatedAt"]
    ) -> MetaOapg.properties.updatedAt:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["cases"]
    ) -> MetaOapg.properties.cases:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["labels"]
    ) -> MetaOapg.properties.labels:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["name"]
    ) -> MetaOapg.properties.name:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["organizationId"]
    ) -> MetaOapg.properties.organizationId:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["archivedAt"]
    ) -> MetaOapg.properties.archivedAt:
        ...

    @typing.overload
    def __getitem__(
        self, name: typing_extensions.Literal["branch"]
    ) -> MetaOapg.properties.branch:
        ...

    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema:
        ...

    def __getitem__(
        self,
        name: typing.Union[
            typing_extensions.Literal[
                "id",
                "createdAt",
                "updatedAt",
                "cases",
                "labels",
                "name",
                "organizationId",
                "archivedAt",
                "branch",
            ],
            str,
        ],
    ):
        # dict_instance[name] accessor
        return super().__getitem__(name)

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["id"]
    ) -> MetaOapg.properties.id:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["createdAt"]
    ) -> MetaOapg.properties.createdAt:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["updatedAt"]
    ) -> MetaOapg.properties.updatedAt:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["cases"]
    ) -> MetaOapg.properties.cases:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["labels"]
    ) -> MetaOapg.properties.labels:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["name"]
    ) -> MetaOapg.properties.name:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["organizationId"]
    ) -> MetaOapg.properties.organizationId:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["archivedAt"]
    ) -> typing.Union[MetaOapg.properties.archivedAt, schemas.Unset]:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: typing_extensions.Literal["branch"]
    ) -> typing.Union[MetaOapg.properties.branch, schemas.Unset]:
        ...

    @typing.overload
    def get_item_oapg(
        self, name: str
    ) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]:
        ...

    def get_item_oapg(
        self,
        name: typing.Union[
            typing_extensions.Literal[
                "id",
                "createdAt",
                "updatedAt",
                "cases",
                "labels",
                "name",
                "organizationId",
                "archivedAt",
                "branch",
            ],
            str,
        ],
    ):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[
            dict,
            frozendict.frozendict,
        ],
        organizationId: typing.Union[
            MetaOapg.properties.organizationId,
            str,
        ],
        createdAt: typing.Union[
            MetaOapg.properties.createdAt,
            str,
            datetime,
        ],
        cases: typing.Union[
            MetaOapg.properties.cases,
            list,
            tuple,
        ],
        name: typing.Union[
            MetaOapg.properties.name,
            str,
        ],
        id: typing.Union[
            MetaOapg.properties.id,
            str,
            uuid.UUID,
        ],
        labels: typing.Union[
            MetaOapg.properties.labels,
            list,
            tuple,
        ],
        updatedAt: typing.Union[
            MetaOapg.properties.updatedAt,
            str,
            datetime,
        ],
        archivedAt: typing.Union[
            MetaOapg.properties.archivedAt, None, str, datetime, schemas.Unset
        ] = schemas.unset,
        branch: typing.Union[
            MetaOapg.properties.branch, None, str, schemas.Unset
        ] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[
            schemas.AnyTypeSchema,
            dict,
            frozendict.frozendict,
            str,
            date,
            datetime,
            uuid.UUID,
            int,
            float,
            decimal.Decimal,
            None,
            list,
            tuple,
            bytes,
        ],
    ) -> "TestSet":
        return super().__new__(
            cls,
            *_args,
            organizationId=organizationId,
            createdAt=createdAt,
            cases=cases,
            name=name,
            id=id,
            labels=labels,
            updatedAt=updatedAt,
            archivedAt=archivedAt,
            branch=branch,
            _configuration=_configuration,
            **kwargs,
        )


from gentrace.model.test_case import TestCase
